Index: trunk/MagicSoft/Mars/Changelog
===================================================================
--- trunk/MagicSoft/Mars/Changelog	(revision 8850)
+++ trunk/MagicSoft/Mars/Changelog	(revision 8851)
@@ -18,4 +18,14 @@
 
                                                  -*-*- END OF LINE -*-*-
+
+ 2008/02/01 Stefan Ruegamer
+
+   * datacenter/macros/filldotrun.C
+     - added default entry for fCompmux for new runs
+
+   * datacenter/macros/checkfileavail.C
+     - added checking of fCompmux
+
+
 
  2008/02/01 Daniel Hoehne
Index: trunk/MagicSoft/Mars/datacenter/macros/filldotrun.C
===================================================================
--- trunk/MagicSoft/Mars/datacenter/macros/filldotrun.C	(revision 8850)
+++ trunk/MagicSoft/Mars/datacenter/macros/filldotrun.C	(revision 8851)
@@ -618,5 +618,5 @@
 
         //create entry in table RunProcessStatus for this runnumber
-        TString query2=Form("INSERT RunProcessStatus SET fRunNumber=%d, fTimingCorrection='1970-01-01 00:00:00'",
+        TString query2=Form("INSERT RunProcessStatus SET fRunNumber=%d, fTimingCorrection='1970-01-01 00:00:00', fCompmux='1970-01-01 00:00:00'",
                             runnumber);
         if (testflagkey==3)

Index: trunk/MagicSoft/Mars/datacenter/macros/checkfileavail.C
===================================================================
--- trunk/MagicSoft/Mars/datacenter/macros/checkfileavail.C	(revision 8850)
+++ trunk/MagicSoft/Mars/datacenter/macros/checkfileavail.C	(revision 8851)
@@ -128,5 +128,5 @@
     //check for each run the availability of files from the table RunProcessStatus
     //the following columns have to be checked:
     //fCCFileAvail, fCaCoFileAvail, fCaCoFileFound, fRawFileAvail, fTimingCorrection
     //fTimingCorrection has to be checked, as only rawfiles with correct timing should be calibrated
     TSQLRow *row=0;
@@ -140,4 +140,5 @@
             || GetStatus(serv, rc, runno, "RunProcessStatus", "fCaCoFileFound").IsNull()
             || GetStatus(serv, rc, runno, "RunProcessStatus", "fTimingCorrection").IsNull()
+            || GetStatus(serv, rc, runno, "RunProcessStatus", "fCompmux").IsNull()
 //            || GetStatus(serv, rc, runno, "RunProcessStatus", "fTimingCorrection")=="1970-01-01 00:00:00"
             || GetStatus(serv, rc, runno, "RunProcessStatus", "fRawFileAvail").IsNull())
@@ -128,5 +128,5 @@
     //check for each run the availability of files from the table RunProcessStatus
     //the following columns have to be checked:
-    //fCCFileAvail, fCaCoFileAvail, fCaCoFileFound, fRawFileAvail, fTimingCorrection
+    //fCCFileAvail, fCaCoFileAvail, fCaCoFileFound, fRawFileAvail, fTimingCorrection, fCompmux
     //fTimingCorrection has to be checked, as only rawfiles with correct timing should be calibrated
     TSQLRow *row=0;